## 期权合约信息

接口：opt_basic

描述：获取期权合约信息

积分：用户需要至少5000积分可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS期权代码 |
| exchange | str | N | 交易所代码 （包括上交所SSE等交易所） |
| opt_code | str | N | 标准合约代码，OP+期货合约TS_CODE，如棕榈油2207合约，输入OPP2207.DCE |
| call_put | str | N | 期权类型 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS代码 |
| exchange | str | Y | 交易市场 |
| name | str | Y | 合约名称 |
| per_unit | str | Y | 合约单位 |
| opt_code | str | Y | 标的合约代码 |
| opt_type | str | Y | 合约类型 |
| call_put | str | Y | 期权类型 |
| exercise_type | str | Y | 行权方式 |
| exercise_price | float | Y | 行权价格 |
| s_month | str | Y | 结算月 |
| maturity_date | str | Y | 到期日 |
| list_price | float | Y | 挂牌基准价 |
| list_date | str | Y | 开始交易日期 |
| delist_date | str | Y | 最后交易日期 |
| last_edate | str | Y | 最后行权日期 |
| last_ddate | str | Y | 最后交割日期 |
| quote_unit | str | Y | 报价单位 |
| min_price_chg | str | Y | 最小价格波幅 |

接口示例

```python
pro = ts.pro_api('your token')

df = pro.opt_basic(exchange='DCE', fields='ts_code,name,exercise_type,list_date,delist_date')
```

数据示例

```python
ts_code            name             exercise_type list_date delist_date
0    M1707-C-2400.DCE  豆粕期权1707认购2400            美式  20170605    20170607
```